@@ -1,28 +1,6 @@
 #include <Rcpp.h>
 using namespace Rcpp;
 
-//' @keywords internal
-// [[Rcpp::export]]
-NumericVector get_curve_start(NumericVector acc, NumericVector peaks_idx) {
-
-    int n = peaks_idx.size();
-    double dF = 0;
-    NumericVector curve_start(n);
-
-    for (int i = 0; i < n; ++i) {
-        for (int j = peaks_idx[i] - 1; j > 0; --j) {
-            dF = acc[j + 1] - acc[j - 1];
-            if (dF < 0) {
-                curve_start[i] = j;
-                break;
-            }
-        }
-    }
-
-    return curve_start;
-
-}
-
 //' @keywords internal
 // [[Rcpp::export]]
 NumericVector compute_peak_acc_rate(NumericVector acc, NumericVector start_idx,
